### ===================================================================================================================
###                                        VIIA - Example script foundations
### ===================================================================================================================
# Copyright VIIA

# =====================================================================================================================
#                                                    INITIAL SETUP
# =====================================================================================================================

# Import the viiaPackage
from viiapackage import *

# Set up the project information
project = viia_create_project('test-create_foundation')

# Create a grid
grid_points = []
for i in range(5):
    x1 = i * 10
    x2 = i * 10 + 5
    grid_points.append(x1)
    grid_points.append(x2)
grid = project.viia_create_orthogonal_grid([grid_points, [0, 3]])

# Create some walls to apply different foundation details on
foundation_details = {}
for i in range(7):
    x1 = i * 10
    x2 = i * 10 + 5
    foundation_details[f"Foundation type {chr(ord('@')+i+1)}"] = {
        'walls': [
            project.viia_create_wall(
                'N0', material='MW-KLEI<1945', geometry=200,
                points=[[[x1, 0, 0], [x2, 0, 0], [x2, 0, 2.9], [x1, 0, 2.9]]]),
            project.viia_create_wall(
                'N0', material='MW-KLEI<1945', geometry=200,
                points=[[[x2, 0, 0], [x2, 3, 0], [x2, 3, 2.9], [x2, 0, 2.9]]]),
            project.viia_create_wall(
                'N0', material='MW-KLEI>1945', geometry=100,
                points=[[[x2, 3, 0], [x1, 3, 0], [x1, 3, 2.9], [x2, 3, 2.9]]]),
            project.viia_create_wall(
                'N0', material='MW-KLEI>1945', geometry=100,
                points=[[[x1, 3, 0], [x1, 0, 0], [x1, 0, 2.9], [x1, 3, 2.9]]])]}

# =====================================================================================================================
#                                             EXAMPLES FOUNDATION DETAILS
# =====================================================================================================================

# Foundation detail type A (regular)
data = foundation_details['Foundation type A']
data['fwalls'], data['fstrips'] = project.viia_create_foundation_walls_and_strips(
    walls=data['walls'], strip_material='LIN-BETON', strip_width=450, strip_thickness=150, foundation_depth=-0.8)

# Foundation detail type B (stepped foundation)
data = foundation_details['Foundation type B']
data['fwalls'], data['fstrips'] = project.viia_create_foundation_walls_and_strips(
    walls=data['walls'], stepped_foundation_strip_extensions=[55, 75],
    stepped_foundation_strip_heights=[120, 150], foundation_depth=-0.8)

# Foundation detail type C (Regular Cavity wall)
data = foundation_details['Foundation type C']
data['cavity walls'] = project.viia_create_cavity_wall_ties_from_list(
    data['walls'], cavity=0.1, dummy_plates=False, outer_wall_material='MW-KLEI>1945', no_ties=True)
data['fwalls'], data['fstrips'] = project.viia_create_foundation_walls_and_strips(
    walls=data['walls'], strip_material='LIN-BETON', strip_width=650, strip_thickness=150, foundation_depth=-0.8)

# Foundation detail type D (Cavity wall stepped foundation, filled to top)
data = foundation_details['Foundation type D']
data['cavity walls'] = project.viia_create_cavity_wall_ties_from_list(
    data['walls'], cavity=0.1, dummy_plates=False, outer_wall_material='MW-KLEI>1945', outer_wall_thickness=0.1,
    no_ties=True)
data['fwalls'], data['fstrips'] = project.viia_create_foundation_walls_and_strips(
    walls=data['walls'], strip_material='LIN-MW-KLEI<1945', stepped_foundation_strip_extensions=[55, 75],
    stepped_foundation_strip_heights=[120, 150], foundation_depth=-0.8)

# Foundation detail type E (Cavity wall stepped foundation, half filled)
data = foundation_details['Foundation type E']
data['cavity walls'] = project.viia_create_cavity_wall_ties_from_list(
    data['walls'], cavity=0.1, dummy_plates=False, outer_wall_material='MW-KLEI>1945', outer_wall_thickness=0.1,
    no_ties=True)
data['fwalls'], data['fstrips'] = project.viia_create_foundation_walls_and_strips(
    walls=data['walls'], stepped_foundation_strip_extensions=[55, 75], stepped_foundation_strip_heights=[120, 150],
    foundation_depth=-0.8, cavity_extension=200)

# =====================================================================================================================
#                                               PLOT FOUNDATION DETAILS
# =====================================================================================================================

# Only create the plots for the foundation
project.viia_plot_foundation_details(save_folder=Path.cwd(), dpi=300)

# Finalise script
project.viia_print_execution_time()

# =====================================================================================================================
#                                                   END OF SCRIPT
# =====================================================================================================================
